==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/StrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialIndicatorDescriptionMetadata } from "./FinancialIndicatorDescriptionMetadata";
/**
 * @hidden
 */
var StrategyBasedIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StrategyBasedIndicatorDescriptionMetadata, _super);
    function StrategyBasedIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StrategyBasedIndicatorDescriptionMetadata.b = function (a) {
        if (StrategyBasedIndicatorDescriptionMetadata.a == null) {
            StrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StrategyBasedIndicatorDescriptionMetadata.c(StrategyBasedIndicatorDescriptionMetadata.a);
        }
        if (a.j(StrategyBasedIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.c = function (a) {
        FinancialIndicatorDescriptionMetadata.c(a);
    };
    StrategyBasedIndicatorDescriptionMetadata.d = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.b(a);
        a.z("StrategyBasedIndicator", StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.$t = markType(StrategyBasedIndicatorDescriptionMetadata, 'StrategyBasedIndicatorDescriptionMetadata');
    StrategyBasedIndicatorDescriptionMetadata.a = null;
    return StrategyBasedIndicatorDescriptionMetadata;
}(Base));
export { StrategyBasedIndicatorDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/StrategyBasedIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialIndicatorDescriptionMetadata } from "./FinancialIndicatorDescriptionMetadata";
/**
 * @hidden
 */
var StrategyBasedIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(StrategyBasedIndicatorDescriptionMetadata, _super);
    function StrategyBasedIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StrategyBasedIndicatorDescriptionMetadata.b = function (a) {
        if (StrategyBasedIndicatorDescriptionMetadata.a == null) {
            StrategyBasedIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StrategyBasedIndicatorDescriptionMetadata.c(StrategyBasedIndicatorDescriptionMetadata.a);
        }
        if (a.k(StrategyBasedIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.aa(StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.c = function (a) {
        FinancialIndicatorDescriptionMetadata.c(a);
    };
    StrategyBasedIndicatorDescriptionMetadata.d = function (a) {
        StrategyBasedIndicatorDescriptionMetadata.b(a);
        a.ab("StrategyBasedIndicator", StrategyBasedIndicatorDescriptionMetadata.a);
    };
    StrategyBasedIndicatorDescriptionMetadata.$t = markType(StrategyBasedIndicatorDescriptionMetadata, 'StrategyBasedIndicatorDescriptionMetadata');
    StrategyBasedIndicatorDescriptionMetadata.a = null;
    return StrategyBasedIndicatorDescriptionMetadata;
}(Base));
export { StrategyBasedIndicatorDescriptionMetadata };
